@@ -1856,7 +1856,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "CloudFilestoreManagerClient":
         return self
 
     def __exit__(self, type, value, traceback):
